# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/postgres/access'
require 'easy_type'

Puppet::Type.type(:pg_record).provide(:psql) do
  include EasyType::Provider
  include EasyType::Template
  include EasyType::Helpers
  include Puppet_X::EnterpriseModules::Postgres::Access

  desc 'Manage a record in an Postgres table via regular SQL'

  mk_resource_methods

  def self.prefetch(resources)
    resources.each do |_name, resource|
      options = options_for(resource[:role], resource[:password], db_from(resource))
      columns = resource.data.keys.collect { |c| "#{c}||'#{' '.*c.length}' as #{c}" }
      statement = "select #{columns.join(',')} from #{resource[:table_name]} where #{resource[:key_name]} = '#{resource[:key_value]}'"
      records = sql(statement, options)
      resource.provider = map_raw_to_resource(records.last) unless records.empty?
    end
  end

  def self.options_for(role, password, db)
    options = { :db => db }
    options[:username] = role
    password = password.nil? ? role : password
    options[:password] = password
    options
  end
end
