# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'puppet/property/boolean'

# Define the pg_register type
module Puppet
  Type.newtype(:pg_register) do
    include EasyType::YamlType

    def self.module_name
      'pg_config'
    end

    config_file '/etc/pg_register.yaml'

    desc <<-DOC
    This resource allows you to set the defaults for all other pg types.


    Here is an example on how to create the `default` settings:

        pg_register { '<DB>':
          default        => true|false,
          user           => '<username>',
          password       => '<password>',
          connect_string => "[//]host[:port][/service_name][:server][/instance]",
        }

    If you want to manage a remote database, like for instance `DB1`. You will have to specify a local pgcle_home from where sqlplus can be started.
    You use `pg_register` like this:

        pg_register { 'DB1':
          default        => true,
          user           => 'postgres',
          password       => 'password',
          connect_string => '//host1:1522/DB1',
          pluggable      => false,

    DOC

    parameter :name

    property :default
    property :user
    property :os_user
    property :password
    property :database
    property :connect_string
    property :daemonized
  end
end
