# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:daemonized, :boolean => true, :parent => Puppet::Property::Boolean) do
  include EasyType::YamlProperty

  desc <<-EOD
  Use daemonized sqlplus process for processing.

  By default Puppet will create a new sqlplus session for every set of information
  it needs to retrieve. This can put some strain on the Oracle database. When you
  want to decrease this, you can set the daemonized setting to true. This wil create
  a single daemon process for every database it needs to connect to and share
  this process for all sql processing.

  This is however more prone to instability. So use with care.

  The default value is `true` e.g. run sqlplus as a daemon.

      pg_register {'mydb'
        ...
        daemonized => true,
        ...
      }

  Not yet supported

  EOD

  data_type('Optional[Boolean]')

  # rubocop: disable Lint/BooleanSymbol
  defaultto :false
  newvalues(:true, :false)
  # rubocop: enable Lint/BooleanSymbol
end
