# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:default, :boolean => true, :parent => Puppet::Property::Boolean) do
  include EasyType::YamlProperty

  desc <<-EOD
    When you set this value to true, this database will be used when no explcit `sid` is specified on the
    Oracle types.

    Many of the of the postgres types, allow you to NOT specfify the `db` and use a default `db`. This makes
    puppet manifests easier readable and less verbose when creating a manifest for a single database.

    The databasse for which you set the property `default` to `true`, is the database that will be used for those
    operations.

  EOD

  # rubocop: disable Lint/BooleanSymbol
  defaultto :false
  newvalues(:true, :false)
  # rubocop: enable Lint/BooleanSymbol

  data_type('Boolean')

  on_apply do
    reset_defaults if value
    resource.class.configuration[resource[:name]]['default'] = value
    nil
  end

  def reset_defaults
    resource.class.configuration.each { |_k, v| v['default'] = false }
  end
end
