# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:create_only, :array_matching => :all) do
  include EasyType

  defaultto []

  validate do |value|
    fail 'You need to specify an Array instead of a comma separated string' if value.include?(',')
  end

  data_type('Array[String[1]]')
  desc <<-DOC
    The attributes from `pg_user` you only want to manage when you create a user.
    This is usefull when defining postgres role for REAL users. Users that
    are supposed to change the password and the account expirery.
    Here is an example:

        pg_role {'scott':
          password    => 'secret',
          create_only => ['password'],
        }

    When user `scott` doesn't exists, it will be created. After the first run the property `password`
    is not updated anymore. Even when there is a difference between the manifest and reality.

  DOC
end
