# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/postgres/mungers'

newparam(:schema_name) do
  include EasyType
  include EasyType::Validators::Name

  isnamevar

  desc <<-EOD
    The schema name.

    The schema name is part of the title of the resource. In this example:

        pg_schema_definition{'MYAPP@SID':
          ensure => latest,
          password => 'secret',
          ...
        }

    The schema name is the part of the title before the `@` character. In this case `MYAPP`.
    The puppet type uses this as the Postgres user to log in. Yo must specify the password in the
    resource definition.

  EOD

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('application').upcase
  end
end
