# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type
#
Puppet::Type.newtype(:pg_tablespace) do
  include EasyType
  include Puppet_X::EnterpriseModules::Postgres::Access
  include Puppet_X::EnterpriseModules::Postgres::Utilities
  extend Puppet_X::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This puppet type allows you to create drop and manage postgres tablespaces. Here is an example on how you could use it:

      pg_tablespace {'my_ts@localhost:
        location => '/u01/pg_data',
        owner    => 'my_role',
      }

  The `pg_tablespace` type recognises all of the options you also have when using SQL to create a user or a role.

  DOC

  ensurable

  to_get_raw_resources do
    sql_on_all_databases <<-SQL
      select
        ts.oid as oid,
        ts.spcname as spcname,
        pg_tablespace_location(ts.oid) as location,
        auth.rolname as rolname
      from pg_tablespace ts, pg_authid auth
      where
        ts.spcowner = auth.oid
    SQL
  end

  on_create do
    [:sql, "create tablespace #{tablespace_name}", { :db => db }]
  end

  on_modify do
    [:sql, "alter tablespace #{tablespace_name}", { :skip_without_properties => true, :db => db }]
  end

  on_destroy do
    [:sql, "drop tablespace #{tablespace_name}", { :db => db }]
  end

  map_title_to_db(:tablespace_name)

  parameter :name
  parameter :tablespace_name
  parameter :db

  property :oid
  property :owner
  property :location
end
