# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
require 'puppet'
module_path = Pathname.new(__FILE__).dirname.parent.parent.parent.parent.parent
$LOAD_PATH.unshift("#{module_path}pg_configlib")
$LOAD_PATH.unshift("#{module_path}easy_typelib")
require 'easy_type/preamble'
require 'easy_type/setup'
require 'puppet_x/enterprisemodules/postgres/access'

module PuppetX
  # Doc
  module Postgres
    # Docs
    # TODO: Write documentation
    module Fact
      def pg_array_fact_all(mappings = {}, &proc)
        query_routine = lambda { |query| sql_on_all_database_sids(query) }
        mapper        = lambda { |results, lambda_mappings| array_mapper(results, lambda_mappings) }
        pg_fact_internal(query_routine, mapper, mappings, &proc)
      end

      def pg_array_fact(mappings = {}, &proc)
        query_routine = lambda { |query| sql_on_all_databases(query) }
        mapper        = lambda { |results, lambda_mappings| array_mapper(results, lambda_mappings) }
        pg_fact_internal(query_routine, mapper, mappings, &proc)
      end

      def pg_record_fact(mappings = {}, &proc)
        query_routine = lambda { |query| sql_on_all_databases(query) }
        mapper        = lambda { |results, lambda_mappings| record_mapper(results, lambda_mappings) }
        pg_fact_internal(query_routine, mapper, mappings, &proc)
      end

      def pg_fact_internal(query_routine, mapper, mappings = {})
        query = yield
        setcode do
          extend Puppet_X::EnterpriseModules::Postgres::Access
          extend EasyType::Helpers

          results = query_routine.call(query)
          mapper.call(results, mappings)
        end
      end

      def no_mappings(result)
        result.delete('SID')
        result[result.keys.first]
      end

      def array_mapper(results, mappings)
        results.collect do |result|
          if mappings == {}
            no_mappings(result)
          else
            return_value = mappings.collect do |key, entry|
              [key.to_s, result[entry]]
            end.flatten
            Hash[*return_value]
          end
        end
      end

      def record_mapper(result, mappings)
        result = result.first
        if mappings == {}
          no_mappings(result)
        else
          return_value = mappings.collect do |key, entry|
            [key.to_s, result[entry]]
          end
          return_value.to_h
        end
      end
    end
  end
end
